searchData={"items":[{"type":"module","title":"LiveExWebRTC.Player","doc":"Component for sending and playing audio and video via WebRTC from a Phoenix app to a browser (browser subscribes).\n\nIt:\n* renders a single HTMLVideoElement\n* creates WebRTC PeerConnection both on the server and client side\n* connects those two peer connections negotiating a single audio and a single video track\n* attaches audio and video on the client side to the HTMLVideoElement\n* subscribes to the configured PubSub where it expects audio and video packets and sends them to the client side.\n\nWhen `LiveExWebRTC.Publisher` is used, audio an video packets are delivered automatically,\nassuming both components are configured with the same PubSub.\n\nIf `LiveExWebRTC.Publisher` is not used, you should send packets to the\n`streams:audio:#{publisher_id}` and `streams:video:#{publisher_id}` topics.\n\nKeyframe requests are sent under `publishers:#{publisher_id}` topic.","ref":"LiveExWebRTC.Player.html"},{"type":"module","title":"JavaScript Hook - LiveExWebRTC.Player","doc":"Player live view requires JavaScript hook to be registered under `Player` name.\nThe hook can be created using `createPlayerHook` function.\nFor example:\n\n```javascript\nimport { createPlayerHook } from \"live_ex_webrtc\";\nlet Hooks = {};\nconst iceServers = [{ urls: \"stun:stun.l.google.com:19302\" }];\nHooks.Player = createPlayerHook(iceServers);\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  // ...\n  hooks: Hooks\n});\n```","ref":"LiveExWebRTC.Player.html#module-javascript-hook"},{"type":"module","title":"Examples - LiveExWebRTC.Player","doc":"```elixir\ndefmodule LiveTwitchWeb.StreamViewerLive do\n  use LiveTwitchWeb, :live_view\n\n  alias LiveExWebRTC.Player\n\n  @impl true\n  def render(assigns) do\n  ~H\"\"\"\n   \n  \"\"\"\n  end\n\n  @impl true\n  def mount(_params, _session, socket) do\n    socket = Player.attach(socket, id: \"player\", publisher_id: \"publisher\", pubsub: LiveTwitch.PubSub)\n    {:ok, socket}\n  end\nend\n```","ref":"LiveExWebRTC.Player.html#module-examples"},{"type":"function","title":"LiveExWebRTC.Player.attach/2","doc":"Attaches required hooks and creates `t:t/0` struct.\n\nCreated struct is saved in socket's assigns and has to be passed to `LiveExWebRTC.Player.live_render/1`.\n\nOptions:\n* `id` - player id. This is typically your user id (if there is users database).\nIt is used to identify live view and generated HTML video player.\n* `publisher_id` - publisher id that this player is going to subscribe to.\n* `pubsub` - a pubsub that player live view will subscribe to for audio and video packets. See module doc for more.\n* `on_connected` - callback called when the underlying peer connection changes its state to the `:connected`. See `t:on_connected/0`.\n* `on_packet` - callback called for each audio and video RTP packet. Can be used to modify the packet before sending via WebRTC to the other side. See `t:on_packet/0`.\n* `ice_servers` - a list of `t:ExWebRTC.PeerConnection.Configuration.ice_server/0`,\n* `ice_ip_filter` - `t:ExICE.ICEAgent.ip_filter/0`,\n* `ice_port_range` - `t:Enumerable.t(non_neg_integer())/1`,\n* `audio_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `video_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `pc_genserver_opts` - `t:GenServer.options/0` for the underlying `ExWebRTC.PeerConnection` process.\n* `class` - a list of CSS/Tailwind classes that will be applied to the HTMLVideoPlayer. Defaults to \"\".","ref":"LiveExWebRTC.Player.html#attach/2"},{"type":"function","title":"LiveExWebRTC.Player.live_render/1","doc":"Helper function for rendering Player live view.","ref":"LiveExWebRTC.Player.html#live_render/1"},{"type":"function","title":"Attributes - LiveExWebRTC.Player.live_render/1","doc":"* `socket` (`Phoenix.LiveView.Socket`) (required) - Parent live view socket.\n* `player` (`LiveExWebRTC.Player`) (required) - Player struct. It is used to pass player id and publisher id to the newly created live view via live view session.\n  This data is then used to do a handshake between parent live view and child live view during which child live view receives\n  the whole Player struct.\n\n* `class` (`:string`) - CSS/Tailwind classes for styling HTMLVideoElement. Defaults to `nil`.","ref":"LiveExWebRTC.Player.html#live_render/1-attributes"},{"type":"type","title":"LiveExWebRTC.Player.on_connected/0","doc":"","ref":"LiveExWebRTC.Player.html#t:on_connected/0"},{"type":"type","title":"LiveExWebRTC.Player.on_packet/0","doc":"","ref":"LiveExWebRTC.Player.html#t:on_packet/0"},{"type":"type","title":"LiveExWebRTC.Player.t/0","doc":"","ref":"LiveExWebRTC.Player.html#t:t/0"},{"type":"module","title":"LiveExWebRTC.Publisher","doc":"Component for sending audio and video via WebRTC from a browser to a Phoenix app (browser publishes).\n\nIt:\n* renders:\n  * audio and video device selects\n  * audio and video stream configs\n  * stream preview\n  * transmission stats\n* on clicking \"Start Streaming\", creates WebRTC PeerConnection both on the client and server side\n* connects those two peer connections negotiatiing a single audio and video track\n* sends audio and video from selected devices to the live view process\n* publishes received audio and video packets to the configured PubSub\n\nWhen `LiveExWebRTC.Player` is used, audio and video packets are delivered automatically,\nassuming both components are configured with the same PubSub.\n\nIf `LiveExWebRTC.Player` is not used, you should subscribe to `streams:audio:#{publisher_id}`\nand `streams:video:#{publisher_id}` topics.\n\nKeyframe requests should be sent on `publishers:#{publisher_id}` topic e.g.\n\n```elixir\nPubSub.broadcast(LiveTwitch.PubSub, \"publishers:my_publisher\", {:live_ex_webrtc, :keyframe_req})\n```","ref":"LiveExWebRTC.Publisher.html"},{"type":"module","title":"JavaScript Hook - LiveExWebRTC.Publisher","doc":"Publisher live view requires JavaScript hook to be registered under `Publisher` name.\nThe hook can be created using `createPublisherHook` function.\nFor example:\n\n```javascript\nimport { createPublisherHook } from \"live_ex_webrtc\";\nlet Hooks = {};\nconst iceServers = [{ urls: \"stun:stun.l.google.com:19302\" }];\nHooks.Publisher = createPublisherHook(iceServers);\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  // ...\n  hooks: Hooks\n});\n```","ref":"LiveExWebRTC.Publisher.html#module-javascript-hook"},{"type":"module","title":"Examples - LiveExWebRTC.Publisher","doc":"```elixir\ndefmodule LiveTwitchWeb.StreamerLive do\n  use LiveTwitchWeb, :live_view\n\n  alias LiveExWebRTC.Publisher\n\n  @impl true\n  def render(assigns) do\n  ~H\"\"\"\n   \n  \"\"\"\n  end\n\n  @impl true\n  def mount(_params, _session, socket) do\n    socket = Publisher.attach(socket, id: \"publisher\", pubsub: LiveTwitch.PubSub)\n    {:ok, socket}\n  end\nend\n```","ref":"LiveExWebRTC.Publisher.html#module-examples"},{"type":"function","title":"LiveExWebRTC.Publisher.attach/2","doc":"Attaches required hooks and creates `t:t/0` struct.\n\nCreated struct is saved in socket's assigns and has to be passed to `LiveExWebRTC.Publisher.live_render/1`.\n\nOptions:\n* `id` - publisher id. This is typically your user id (if there is users database).\nIt is used to identify live view and generated HTML elements.\n* `pubsub` - a pubsub that publisher live view will use for broadcasting audio and video packets received from a browser. See module doc for more.\n* `on_connected` - callback called when the underlying peer connection changes its state to the `:connected`. See `t:on_connected/0`.\n* `on_packet` - callback called for each audio and video RTP packet. Can be used to modify the packet before publishing it on a pubsub. See `t:on_packet/0`.\n* `ice_servers` - a list of `t:ExWebRTC.PeerConnection.Configuration.ice_server/0`,\n* `ice_ip_filter` - `t:ExICE.ICEAgent.ip_filter/0`,\n* `ice_port_range` - `t:Enumerable.t(non_neg_integer())/1`,\n* `audio_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `video_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `pc_genserver_opts` - `t:GenServer.options/0` for the underlying `ExWebRTC.PeerConnection` process.","ref":"LiveExWebRTC.Publisher.html#attach/2"},{"type":"function","title":"LiveExWebRTC.Publisher.live_render/1","doc":"Helper function for rendering Publisher live view.","ref":"LiveExWebRTC.Publisher.html#live_render/1"},{"type":"function","title":"Attributes - LiveExWebRTC.Publisher.live_render/1","doc":"* `socket` (`Phoenix.LiveView.Socket`) (required) - Parent live view socket.\n* `publisher` (`LiveExWebRTC.Publisher`) (required) - Publisher struct. It is used to pass publisher id to the newly created live view via live view session.\n  This data is then used to do a handshake between parent live view and child live view during which child live\n  view receives the whole Publisher struct.","ref":"LiveExWebRTC.Publisher.html#live_render/1-attributes"},{"type":"type","title":"LiveExWebRTC.Publisher.on_connected/0","doc":"","ref":"LiveExWebRTC.Publisher.html#t:on_connected/0"},{"type":"type","title":"LiveExWebRTC.Publisher.on_packet/0","doc":"","ref":"LiveExWebRTC.Publisher.html#t:on_packet/0"},{"type":"type","title":"LiveExWebRTC.Publisher.t/0","doc":"","ref":"LiveExWebRTC.Publisher.html#t:t/0"},{"type":"extras","title":"LiveExWebRTC","doc":"# LiveExWebRTC\n\n[![Hex.pm](https://img.shields.io/hexpm/v/live_ex_webrtc.svg)](https://hex.pm/packages/live_ex_webrtc)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/live_ex_webrtc)\n\nPhoenix Live Components for Elixir WebRTC.","ref":"readme.html"},{"type":"extras","title":"Installation - LiveExWebRTC","doc":"In your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_ex_webrtc, \"~> 0.3.0\"}\n  ]\nend\n```\n\nIn your `tailwind.config.js`\n\n```js\nmodule.exports = {\n  content: [\n    \"../deps/live_ex_webrtc/**/*.*ex\" // ADD THIS LINE\n  ]\n}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - LiveExWebRTC","doc":"`LiveExWebRTC` comes with two `Phoenix.LiveView`s:\n* `LiveExWebRTC.Publisher` - sends audio and video via WebRTC from a web browser to a Phoenix app (browser publishes)\n* `LiveExWebRTC.Player` - sends audio and video via WebRTC from a Phoenix app to a web browser and plays it in the HTMLVideoElement (browser subscribes)\n\nSee module docs and [live_broadcaster](https://github.com/elixir-webrtc/live_broadcaster) for more.","ref":"readme.html#usage"},{"type":"extras","title":"Local development - LiveExWebRTC","doc":"For local development:\n* include `live_ex_webrtc` in your `mix.exs` via `path` \n* modify `NODE_PATH` env variable in your esbuild configuration, which is located in `config.exs` - this will allow for importing javascript hooks from `live_ex_webrtc`.\n\n  For example:\n\n  ```elixir\n  config :esbuild,\n    # ...\n    default: [\n      # ...\n      env: %{\n        \"NODE_PATH\" => \"#{Path.expand(\"../deps\", __DIR__)}:/path/to/parent/dir/of/live_ex_webrtc\"\n      }\n    ]\n  ```\n\n* modify `content` in `tailwind.config.js` - this will compile tailwind classes used in live components.\n  \n  For example:\n\n  ```js\n  module.exports = {\n    content: [\n      // ...\n      \"../deps/**/*.ex\"\n    ]\n  }\n  ```\n\n> ##","ref":"readme.html#local-development"},{"type":"extras","title":"Important {: .info} - LiveExWebRTC","doc":"> Separate paths with `:` on MacOS/Linux and with `;` on Windows.\n\n> ##","ref":"readme.html#important-info"},{"type":"extras","title":"Important {: .info} - LiveExWebRTC","doc":"> Specify path to live_ex_webrtc's parent directory.","ref":"readme.html#important-info"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}